@@ -141,15 +141,16 @@ class Debug:
                 warning=self._show_warnings and 'error parsing code, call stack too shallow',
             )
 
-        filename = call_frame.f_code.co_filename
         function = call_frame.f_code.co_name
-        if filename.startswith('/'):
-            # make the path relative
-            from pathlib import Path
 
+        from pathlib import Path
+
+        path = Path(call_frame.f_code.co_filename)
+        if path.is_absolute():
+            # make the path relative
             cwd = Path('.').resolve()
             try:
-                filename = str(Path(filename).relative_to(cwd))
+                path = path.relative_to(cwd)
             except ValueError:
                 # happens if filename path is not within CWD
                 pass
@@ -165,7 +166,7 @@ class Debug:
             arguments = list(self._args_inspection_failed(args, kwargs))
         else:
             ex = source.executing(call_frame)
-            # function = ex.code_qualname()
+            function = ex.code_qualname()
             if not ex.node:
                 warning = "executing failed to find the calling node"
                 arguments = list(self._args_inspection_failed(args, kwargs))
@@ -173,7 +174,7 @@ class Debug:
                 arguments = list(self._process_args(ex, args, kwargs))
 
         return self.output_class(
-            filename=filename,
+            filename=str(path),
             lineno=lineno,
             frame=function,
             arguments=arguments,
